# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/ebuy/offer/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Ebuy\\Offer\\": "packages/ebuy/offer/src",
            "Ebuy\\Offer\\Seeders\\": "packages/ebuy/offer/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Ebuy\Offer\Providers\OfferServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Offer'  => Ebuy\Offer\Facades\Offer::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Ebuy\\Offer\\Seeders\\OfferTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Ebuy\Offer\Providers\OfferServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Ebuy\Offer\Providers\OfferServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Ebuy\Offer\Providers\OfferServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/offer/{modulename}

**User**

    http://path-to-route-folder/user/offer/{modulename}

**Public**

    http://path-to-route-folder/offers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/offer/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/offer/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/offer/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/offer/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/offer/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/offer/{modulename}/{slug}
    METHOD: GET