<?php

namespace Ebuy\Offer\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Ebuy\Offer\Interfaces\OfferRepositoryInterface;
use Ebuy\Offer\Repositories\Eloquent\Filters\OfferPublicFilter;
use Ebuy\Offer\Repositories\Eloquent\Presenters\OfferListPresenter;

class OfferPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        OfferRepositoryInterface $offer
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('ebuy.offer.modules'), 'offer', guard_url('offer'));
        $this->repository = $offer;
    }

    /**
     * Show offer's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(OfferPublicFilter::class)
            ->setPresenter(OfferListPresenter::class)
            ->select('offers.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('offer::offer.names'))
            ->view('offer::public.offer.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show offer.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('offer::offer.name'))
            ->view('offer::public.offer.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
