<?php

namespace Ebuy\Offer\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Ebuy\Offer\Http\Requests\OfferRequest;
use Ebuy\Offer\Models\Offer;

/**
 * Admin web controller class.
 */
class OfferWorkflowController extends BaseController
{

    /**
     * Workflow controller function for offer.
     *
     * @param Model   $offer
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(OfferRequest $request, Offer $offer, $step)
    {

        try {

            $offer->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('offer::offer.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/offer/offer/' . $offer->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/offer/offer/' . $offer->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for offer.
     *
     * @param Model   $offer
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Offer $offer, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $offer->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('offer::offer.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('offer::admin.offer.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('offer::admin.offer.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('offer::admin.offer.message', $data)->render();

        }

    }
}
