<?php

namespace Ebuy\Offer\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Ebuy\Offer\Models\Offer;

class OfferPolicy
{

    /**
     * Determine if the given user can view the offer.
     *
     * @param UserPolicyInterface $authUser
     * @param Offer $offer
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Offer $offer)
    {
        if ($authUser->canDo('offer.offer.view') && $authUser->isAdmin()) {
            return true;
        }

        return $offer->user_id == user_id() && $offer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a offer.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('offer.offer.create');
    }

    /**
     * Determine if the given user can update the given offer.
     *
     * @param UserPolicyInterface $authUser
     * @param Offer $offer
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Offer $offer)
    {
        if ($authUser->canDo('offer.offer.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $offer->user_id == user_id() && $offer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given offer.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Offer $offer)
    {
        return $offer->user_id == user_id() && $offer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given offer.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Offer $offer)
    {
        if ($authUser->canDo('offer.offer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given offer.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Offer $offer)
    {
        if ($authUser->canDo('offer.offer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
