<?php

namespace Ebuy\Offer\Workflow;

use Ebuy\Offer\Models\Offer;
use Validator;

class OfferValidator
{

    /**
     * Determine if the given offer is valid for complete status.
     *
     * @param Offer $offer
     *
     * @return bool / Validator
     */
    public function complete(Offer $offer)
    {
        return Validator::make($offer->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given offer is valid for verify status.
     *
     * @param Offer $offer
     *
     * @return bool / Validator
     */
    public function verify(Offer $offer)
    {
        return Validator::make($offer->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given offer is valid for approve status.
     *
     * @param Offer $offer
     *
     * @return bool / Validator
     */
    public function approve(Offer $offer)
    {
        return Validator::make($offer->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given offer is valid for publish status.
     *
     * @param Offer $offer
     *
     * @return bool / Validator
     */
    public function publish(Offer $offer)
    {
        return Validator::make($offer->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given offer is valid for archive status.
     *
     * @param Offer $offer
     *
     * @return bool / Validator
     */
    public function archive(Offer $offer)
    {
        return Validator::make($offer->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given offer is valid for unpublish status.
     *
     * @param Offer $offer
     *
     * @return bool / Validator
     */
    public function unpublish(Offer $offer)
    {
        return Validator::make($offer->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
